#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-KF9EmE8GrDq7WuNuiG91pM
key:                  persistent-qq-2.12.0.7-KF9EmE8GrDq7WuNuiG91pM
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  b5102257cf8166b19f9d8769f9f58736
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-KF9EmE8GrDq7WuNuiG91pM
depends:
    base-4.18.2.1 haskell-src-meta-0.8.16-68Vt1QDfadiHOzfuhh2sWT
    mtl-2.3.1 persistent-2.14.6.1-GEU3f5Qg3bVH7PMKZ9qrSb
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

